@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -36,66 +36,67 @@
 #include "Peer.h"
 #include "PieceStorage.h"
 #include "BtMessageValidator.h"
-#include "LogFactory.h"
-#include "Logger.h"
 
 namespace aria2 {
 
-AbstractBtMessage::AbstractBtMessage(uint8_t id, const std::string& name):
-  BtMessage(id),
-  sendingInProgress(false),
-  invalidate(false),
-  uploading(false),
-  cuid(0),
-  _name(name),
-  _metadataGetMode(false),
-  logger(LogFactory::getInstance())
-{}
-
-AbstractBtMessage::~AbstractBtMessage() {}
-
-void AbstractBtMessage::setPeer(const SharedHandle<Peer>& peer)
+AbstractBtMessage::AbstractBtMessage(uint8_t id, const char* name)
+    : BtMessage(id),
+      invalidate_(false),
+      uploading_(false),
+      cuid_(0),
+      name_(name),
+      pieceStorage_(nullptr),
+      dispatcher_(nullptr),
+      messageFactory_(nullptr),
+      requestFactory_(nullptr),
+      peerConnection_(nullptr),
+      metadataGetMode_(false)
 {
-  this->peer = peer;
 }
 
-bool AbstractBtMessage::validate(std::deque<std::string>& errors)
+AbstractBtMessage::~AbstractBtMessage() = default;
+
+void AbstractBtMessage::setPeer(const std::shared_ptr<Peer>& peer)
 {
-  if(validator.get()) {
-    return validator->validate(errors);
-  } else {
-    return true;
+  peer_ = peer;
+}
+
+void AbstractBtMessage::validate()
+{
+  if (validator_) {
+    validator_->validate();
   }
 }
 
-void
-AbstractBtMessage::setBtMessageValidator(const SharedHandle<BtMessageValidator>& validator) {
-  this->validator = validator;
+void AbstractBtMessage::setBtMessageValidator(
+    std::unique_ptr<BtMessageValidator> validator)
+{
+  validator_ = std::move(validator);
 }
 
-void AbstractBtMessage::setPieceStorage(const SharedHandle<PieceStorage>& pieceStorage)
+void AbstractBtMessage::setPieceStorage(PieceStorage* pieceStorage)
 {
-  this->pieceStorage = pieceStorage;
+  pieceStorage_ = pieceStorage;
 }
 
-void AbstractBtMessage::setBtMessageDispatcher(const WeakHandle<BtMessageDispatcher>& dispatcher)
+void AbstractBtMessage::setBtMessageDispatcher(BtMessageDispatcher* dispatcher)
 {
-  this->dispatcher = dispatcher;
+  dispatcher_ = dispatcher;
 }
 
-void AbstractBtMessage::setPeerConnection(const WeakHandle<PeerConnection>& peerConnection)
+void AbstractBtMessage::setPeerConnection(PeerConnection* peerConnection)
 {
-  this->peerConnection = peerConnection;
+  peerConnection_ = peerConnection;
 }
 
-void AbstractBtMessage::setBtMessageFactory(const WeakHandle<BtMessageFactory>& factory)
+void AbstractBtMessage::setBtMessageFactory(BtMessageFactory* factory)
 {
-  this->messageFactory = factory;
+  messageFactory_ = factory;
 }
 
-void AbstractBtMessage::setBtRequestFactory(const WeakHandle<BtRequestFactory>& factory)
+void AbstractBtMessage::setBtRequestFactory(BtRequestFactory* factory)
 {
-  this->requestFactory = factory;
+  requestFactory_ = factory;
 }
 
 } // namespace aria2
