@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,36 +32,27 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_BITFIELD_MESSAGE_VALIDATOR_H_
-#define _D_BT_BITFIELD_MESSAGE_VALIDATOR_H_
+#ifndef D_BT_BITFIELD_MESSAGE_VALIDATOR_H
+#define D_BT_BITFIELD_MESSAGE_VALIDATOR_H
 
 #include "BtMessageValidator.h"
-#include "BtBitfieldMessage.h"
-#include "bittorrent_helper.h"
 
 namespace aria2 {
 
+class BtBitfieldMessage;
+
 class BtBitfieldMessageValidator : public BtMessageValidator {
 private:
-  const BtBitfieldMessage* message;
-  size_t numPiece;
+  const BtBitfieldMessage* message_;
+  size_t numPiece_;
+
 public:
-  BtBitfieldMessageValidator(const BtBitfieldMessage* message,
-			     size_t numPiece):
-    message(message),
-    numPiece(numPiece) {}
+  BtBitfieldMessageValidator(const BtBitfieldMessage* message, size_t numPiece);
+  ~BtBitfieldMessageValidator();
 
-  virtual bool validate(Errors& error) {
-    // TODO
-    bittorrent::checkBitfield(message->getBitfield(),
-			      message->getBitfieldLength(),
-			      numPiece);
-    return true;
-  }
+  virtual void validate() CXX11_OVERRIDE;
 };
 
-typedef SharedHandle<BtBitfieldMessageValidator> BtBitfieldMessageValidatorHandle;
-
 } // namespace aria2
 
-#endif // _D_BT_BITFIELD_MESSAGE_VALIDATOR_H_
+#endif // D_BT_BITFIELD_MESSAGE_VALIDATOR_H
