@@ -35,38 +35,37 @@
 #include "BtHaveAllMessage.h"
 #include "DlAbortEx.h"
 #include "Peer.h"
-#include "StringFormat.h"
+#include "fmt.h"
 #include "PieceStorage.h"
 #include "message.h"
 
 namespace aria2 {
 
-const std::string BtHaveAllMessage::NAME("have all");
+const char BtHaveAllMessage::NAME[] = "have all";
 
-BtHaveAllMessage::BtHaveAllMessage():ZeroBtMessage(ID, NAME) {}
+BtHaveAllMessage::BtHaveAllMessage() : ZeroBtMessage(ID, NAME) {}
 
-SharedHandle<BtHaveAllMessage> BtHaveAllMessage::create
-(const unsigned char* data, size_t dataLength)
+std::unique_ptr<BtHaveAllMessage>
+BtHaveAllMessage::create(const unsigned char* data, size_t dataLength)
 {
   return ZeroBtMessage::create<BtHaveAllMessage>(data, dataLength);
 }
 
 void BtHaveAllMessage::doReceivedAction()
 {
-  if(!getPeer()->isFastExtensionEnabled()) {
-    throw DL_ABORT_EX
-      (StringFormat("%s received while fast extension is disabled",
-                    toString().c_str()).str());
+  if (!getPeer()->isFastExtensionEnabled()) {
+    throw DL_ABORT_EX(fmt("%s received while fast extension is disabled",
+                          toString().c_str()));
   }
-  if(isMetadataGetMode()) {
+  if (isMetadataGetMode()) {
     return;
   }
   getPieceStorage()->subtractPieceStats(getPeer()->getBitfield(),
                                         getPeer()->getBitfieldLength());
   getPeer()->setAllBitfield();
-  getPieceStorage()->addPieceStats
-    (getPeer()->getBitfield(), getPeer()->getBitfieldLength());
-  if(getPeer()->isSeeder() && getPieceStorage()->downloadFinished()) {
+  getPieceStorage()->addPieceStats(getPeer()->getBitfield(),
+                                   getPeer()->getBitfieldLength());
+  if (getPeer()->isSeeder() && getPieceStorage()->downloadFinished()) {
     throw DL_ABORT_EX(MSG_GOOD_BYE_SEEDER);
   }
 }
