@@ -32,18 +32,18 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_PROGRESS_INFO_FILE_H_
-#define _D_BT_PROGRESS_INFO_FILE_H_
+#ifndef D_BT_PROGRESS_INFO_FILE_H
+#define D_BT_PROGRESS_INFO_FILE_H
 
 #include "common.h"
-#include "SharedHandle.h"
+
 #include <string>
 
 namespace aria2 {
 
 class BtProgressInfoFile {
 public:
-  virtual ~BtProgressInfoFile() {}
+  virtual ~BtProgressInfoFile() = default;
 
   virtual std::string getFilename() = 0;
 
@@ -59,8 +59,6 @@ public:
   virtual void updateFilename() = 0;
 };
 
-typedef SharedHandle<BtProgressInfoFile> BtProgressInfoFileHandle;
-
 } // namespace aria2
 
-#endif // _D_BT_PROGRESS_INFO_FILE_H_
+#endif // D_BT_PROGRESS_INFO_FILE_H
