@@ -41,52 +41,86 @@
 #include "BtRuntime.h"
 #include "BtProgressInfoFile.h"
 #include "bittorrent_helper.h"
+#include "LpdMessageReceiver.h"
+#include "UDPTrackerClient.h"
+#include "NullHandle.h"
 
 namespace aria2 {
 
-SharedHandle<DownloadContext>
-BtRegistry::getDownloadContext(gid_t gid) const
-{
-  return get(gid).downloadContext_;
-}
+BtRegistry::BtRegistry() : tcpPort_{0}, udpPort_{0} {}
 
-SharedHandle<DownloadContext>
-BtRegistry::getDownloadContext(const std::string& infoHash) const
+const std::shared_ptr<DownloadContext>&
+BtRegistry::getDownloadContext(a2_gid_t gid) const
 {
-  SharedHandle<DownloadContext> dctx;
-  for(std::map<gid_t, BtObject>::const_iterator i = pool_.begin(),
-        eoi = pool_.end(); i != eoi; ++i) {
-    if(bittorrent::getTorrentAttrs((*i).second.downloadContext_)->infoHash ==
-       infoHash) {
-      dctx = (*i).second.downloadContext_;
-      break;
-    }
-  }      
-  return dctx;
-}
-
-void BtRegistry::put(gid_t gid, const BtObject& obj)
-{
-  pool_[gid] = obj;
-}
-
-BtObject BtRegistry::get(gid_t gid) const
-{
-  std::map<gid_t, BtObject>::const_iterator i = pool_.find(gid);
-  if(i == pool_.end()) {
-    return BtObject();
-  } else {
-    return (*i).second;
+  auto res = get(gid);
+  if (res) {
+    return res->downloadContext;
+  }
+  else {
+    return getNull<DownloadContext>();
   }
 }
 
-bool BtRegistry::remove(gid_t gid)
+const std::shared_ptr<DownloadContext>&
+BtRegistry::getDownloadContext(const std::string& infoHash) const
 {
-  return pool_.erase(gid);
+  for (auto& kv : pool_) {
+    if (bittorrent::getTorrentAttrs(kv.second->downloadContext)->infoHash ==
+        infoHash) {
+      return kv.second->downloadContext;
+    }
+  }
+  return getNull<DownloadContext>();
 }
 
-void BtRegistry::removeAll() {
-  pool_.clear();
+void BtRegistry::put(a2_gid_t gid, std::unique_ptr<BtObject> obj)
+{
+  pool_[gid] = std::move(obj);
 }
 
+BtObject* BtRegistry::get(a2_gid_t gid) const
+{
+  auto i = pool_.find(gid);
+  if (i == std::end(pool_)) {
+    return nullptr;
+  }
+  else {
+    return (*i).second.get();
+  }
+}
+
+bool BtRegistry::remove(a2_gid_t gid) { return pool_.erase(gid); }
+
+void BtRegistry::removeAll() { pool_.clear(); }
+
+void BtRegistry::setLpdMessageReceiver(
+    const std::shared_ptr<LpdMessageReceiver>& receiver)
+{
+  lpdMessageReceiver_ = receiver;
+}
+
+void BtRegistry::setUDPTrackerClient(
+    const std::shared_ptr<UDPTrackerClient>& tracker)
+{
+  udpTrackerClient_ = tracker;
+}
+
+BtObject::BtObject(
+    const std::shared_ptr<DownloadContext>& downloadContext,
+    const std::shared_ptr<PieceStorage>& pieceStorage,
+    const std::shared_ptr<PeerStorage>& peerStorage,
+    const std::shared_ptr<BtAnnounce>& btAnnounce,
+    const std::shared_ptr<BtRuntime>& btRuntime,
+    const std::shared_ptr<BtProgressInfoFile>& btProgressInfoFile)
+    : downloadContext{downloadContext},
+      pieceStorage{pieceStorage},
+      peerStorage{peerStorage},
+      btAnnounce{btAnnounce},
+      btRuntime{btRuntime},
+      btProgressInfoFile{btProgressInfoFile}
+{
+}
+
+BtObject::BtObject() {}
+
 } // namespace aria2
