@@ -32,32 +32,30 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_SETUP_H_
-#define _D_BT_SETUP_H_
+#ifndef D_BT_SETUP_H
+#define D_BT_SETUP_H
 
 #include "common.h"
+
 #include <vector>
+#include <memory>
 
 namespace aria2 {
 
-class Logger;
 class RequestGroup;
 class DownloadEngine;
 class Option;
 class Command;
 
 class BtSetup {
-private:
-  Logger* logger_;
 public:
   BtSetup();
 
-  void setup(std::vector<Command*>& commands,
-             RequestGroup* requestGroup,
-             DownloadEngine* e,
+  void setup(std::vector<std::unique_ptr<Command>>& commands,
+             RequestGroup* requestGroup, DownloadEngine* e,
              const Option* option);
 };
 
 } // namespace aria2
 
-#endif // _D_BT_SETUP_H_
+#endif // D_BT_SETUP_H
