@@ -33,61 +33,67 @@
  */
 /* copyright --> */
 #include "ByteArrayDiskWriter.h"
-#include "util.h"
 #include "A2STR.h"
+#include "DlAbortEx.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-ByteArrayDiskWriter::ByteArrayDiskWriter() {}
-
-ByteArrayDiskWriter::~ByteArrayDiskWriter() {}
-
-void ByteArrayDiskWriter::clear()
+ByteArrayDiskWriter::ByteArrayDiskWriter(size_t maxLength)
+    : maxLength_(maxLength)
 {
-  buf.str(A2STR::NIL);
 }
 
-void ByteArrayDiskWriter::initAndOpenFile(uint64_t totalLength)
-{
-  clear();
-}
+ByteArrayDiskWriter::~ByteArrayDiskWriter() = default;
 
-void ByteArrayDiskWriter::openFile(uint64_t totalLength) {}
+void ByteArrayDiskWriter::clear() { buf_.str(A2STR::NIL); }
+
+void ByteArrayDiskWriter::initAndOpenFile(int64_t totalLength) { clear(); }
+
+void ByteArrayDiskWriter::openFile(int64_t totalLength) {}
 
 void ByteArrayDiskWriter::closeFile() {}
 
-void ByteArrayDiskWriter::openExistingFile(uint64_t totalLength)
-{
-  openFile();
-}
+void ByteArrayDiskWriter::openExistingFile(int64_t totalLength) { openFile(); }
 
-void ByteArrayDiskWriter::writeData(const unsigned char* data, size_t dataLength, off_t position)
+void ByteArrayDiskWriter::writeData(const unsigned char* data,
+                                    size_t dataLength, int64_t offset)
 {
-  uint64_t length = size();
-  if(length < (uint64_t)position) {
-    buf.seekp(length, std::ios::beg);
-    for(uint64_t i = length; i < (uint64_t)position; ++i) {
-      buf.put('\0');
-    }
-  } else {
-    buf.seekp(position, std::ios::beg);
+  if (offset + dataLength > maxLength_) {
+    throw DL_ABORT_EX(fmt("Maximum length(%lu) exceeded.",
+                          static_cast<unsigned long>(maxLength_)));
   }
-  buf.write(reinterpret_cast<const char*>(data), dataLength);
+  int64_t length = size();
+  if (length < offset) {
+    buf_.seekp(length, std::ios::beg);
+    for (int64_t i = length; i < offset; ++i) {
+      buf_.put('\0');
+    }
+  }
+  else {
+    buf_.seekp(offset, std::ios::beg);
+  }
+  buf_.write(reinterpret_cast<const char*>(data), dataLength);
 }
 
-ssize_t ByteArrayDiskWriter::readData(unsigned char* data, size_t len, off_t position)
+ssize_t ByteArrayDiskWriter::readData(unsigned char* data, size_t len,
+                                      int64_t offset)
 {
-  buf.seekg(position, std::ios::beg);
-  buf.read(reinterpret_cast<char*>(data), len);
-  buf.clear();
-  return buf.gcount();
+  buf_.seekg(offset, std::ios::beg);
+  buf_.read(reinterpret_cast<char*>(data), len);
+  buf_.clear();
+  return buf_.gcount();
 }
 
-uint64_t ByteArrayDiskWriter::size()
+int64_t ByteArrayDiskWriter::size()
 {
-  buf.seekg(0, std::ios::end);
-  buf.clear();
-  return buf.tellg();
+  buf_.seekg(0, std::ios::end);
+  buf_.clear();
+  return buf_.tellg();
 }
 
+void ByteArrayDiskWriter::setString(const std::string& s) { buf_.str(s); }
+
+std::string ByteArrayDiskWriter::getString() const { return buf_.str(); }
+
 } // namespace aria2
