@@ -42,7 +42,7 @@
 namespace aria2 {
 
 ContentTypeRequestGroupCriteria::ContentTypeRequestGroupCriteria(
-    const char** contentTypes, const char** extensions)
+    const char* const* contentTypes, const char* const* extensions)
     : contentTypes_(contentTypes), extensions_(extensions)
 {
 }
