@@ -34,9 +34,7 @@
 /* copyright --> */
 #include "DHTAutoSaveCommand.h"
 
-#include <cerrno>
 #include <cstring>
-#include <fstream>
 
 #include "DHTRoutingTable.h"
 #include "DHTNode.h"
@@ -44,62 +42,62 @@
 #include "DHTRoutingTableSerializer.h"
 #include "RecoverableException.h"
 #include "DownloadEngine.h"
-#include "util.h"
 #include "DHTBucket.h"
 #include "RequestGroupMan.h"
 #include "prefs.h"
 #include "Option.h"
 #include "message.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "a2functional.h"
 #include "FileEntry.h"
 #include "DlAbortEx.h"
-#include "StringFormat.h"
-#include "ServerStatMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-DHTAutoSaveCommand::DHTAutoSaveCommand
-(cuid_t cuid, DownloadEngine* e, int family, time_t interval):
-  TimeBasedCommand(cuid, e, interval),
-  family_(family) {}
+DHTAutoSaveCommand::DHTAutoSaveCommand(cuid_t cuid, DownloadEngine* e,
+                                       int family,
+                                       std::chrono::seconds interval)
+    : TimeBasedCommand{cuid, e, std::move(interval)},
+      family_{family},
+      routingTable_{nullptr}
+{
+}
 
-DHTAutoSaveCommand::~DHTAutoSaveCommand() {}
+DHTAutoSaveCommand::~DHTAutoSaveCommand() = default;
 
 void DHTAutoSaveCommand::preProcess()
 {
-  if(getDownloadEngine()->getRequestGroupMan()->downloadFinished() ||
-     getDownloadEngine()->isHaltRequested()) {
+  if (getDownloadEngine()->getRequestGroupMan()->downloadFinished() ||
+      getDownloadEngine()->isHaltRequested()) {
     save();
     enableExit();
   }
 }
 
-void DHTAutoSaveCommand::process()
-{
-  save();
-}
+void DHTAutoSaveCommand::process() { save(); }
 
 void DHTAutoSaveCommand::save()
 {
-  std::string dhtFile =
-    getDownloadEngine()->getOption()->
-    get(family_ == AF_INET? PREF_DHT_FILE_PATH : PREF_DHT_FILE_PATH6);
-  getLogger()->info("Saving DHT routing table to %s.", dhtFile.c_str());
+  std::string dhtFile = getDownloadEngine()->getOption()->get(
+      family_ == AF_INET ? PREF_DHT_FILE_PATH : PREF_DHT_FILE_PATH6);
+  A2_LOG_INFO(fmt("Saving DHT routing table to %s.", dhtFile.c_str()));
 
-  std::string tempFile = dhtFile;
-  tempFile += "__temp";
-  File(tempFile).mkdirs();
-  std::vector<SharedHandle<DHTNode> > nodes;
-  std::vector<SharedHandle<DHTBucket> > buckets;
+  // Removing tempFile is unnecessary because the file is truncated on
+  // open.  But the bug in 1.10.4 creates directory for this path.
+  // Because it is directory, opening directory as file fails.  So we
+  // first remove it here.
+  File tempFile(dhtFile + "__temp");
+  tempFile.remove();
+
+  File(File(dhtFile).getDirname()).mkdirs();
+  std::vector<std::shared_ptr<DHTNode>> nodes;
+  std::vector<std::shared_ptr<DHTBucket>> buckets;
   routingTable_->getBuckets(buckets);
-  for(std::vector<SharedHandle<DHTBucket> >::const_iterator i = buckets.begin(),
-        eoi = buckets.end(); i != eoi; ++i) {
-    const SharedHandle<DHTBucket>& bucket = *i;
-    std::vector<SharedHandle<DHTNode> > goodNodes;
-    bucket->getGoodNodes(goodNodes);
+  for (const auto& b : buckets) {
+    std::vector<std::shared_ptr<DHTNode>> goodNodes;
+    b->getGoodNodes(goodNodes);
     nodes.insert(nodes.end(), goodNodes.begin(), goodNodes.end());
   }
 
@@ -108,32 +106,21 @@ void DHTAutoSaveCommand::save()
   serializer.setNodes(nodes);
 
   try {
-    {
-      std::ofstream o(tempFile.c_str(), std::ios::out|std::ios::binary);
-      if(!o) {
-        throw DL_ABORT_EX
-          (StringFormat("Failed to save DHT routing table to %s. cause:%s",
-                        dhtFile.c_str(), strerror(errno)).str());
-      }
-      serializer.serialize(o);
-    }
-    if(!File(tempFile).renameTo(dhtFile)) {
-      getLogger()->error("Cannot move file from %s to %s.",
-                         tempFile.c_str(), dhtFile.c_str());
-    }
-  } catch(RecoverableException& e) {
-    getLogger()->error("Exception caught while saving DHT routing table to %s",
-                       e, dhtFile.c_str());
+    serializer.serialize(dhtFile);
+  }
+  catch (RecoverableException& e) {
+    A2_LOG_ERROR_EX(fmt("Exception caught while saving DHT routing table to %s",
+                        dhtFile.c_str()),
+                    e);
   }
 }
 
-void DHTAutoSaveCommand::setLocalNode(const SharedHandle<DHTNode>& localNode)
+void DHTAutoSaveCommand::setLocalNode(const std::shared_ptr<DHTNode>& localNode)
 {
   localNode_ = localNode;
 }
 
-void DHTAutoSaveCommand::setRoutingTable
-(const SharedHandle<DHTRoutingTable>& routingTable)
+void DHTAutoSaveCommand::setRoutingTable(DHTRoutingTable* routingTable)
 {
   routingTable_ = routingTable;
 }
