@@ -32,15 +32,15 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DHT_MESSAGE_TRACKER_H_
-#define _D_DHT_MESSAGE_TRACKER_H_
+#ifndef D_DHT_MESSAGE_TRACKER_H
+#define D_DHT_MESSAGE_TRACKER_H
 
 #include "common.h"
 
 #include <utility>
 #include <deque>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "a2time.h"
 #include "ValueBase.h"
 
@@ -52,43 +52,41 @@ class DHTMessageCallback;
 class DHTRoutingTable;
 class DHTMessageFactory;
 class DHTMessageTrackerEntry;
-class Logger;
 
 class DHTMessageTracker {
 private:
-  std::deque<SharedHandle<DHTMessageTrackerEntry> > entries_;
-  
-  SharedHandle<DHTRoutingTable> routingTable_;
+  std::deque<std::unique_ptr<DHTMessageTrackerEntry>> entries_;
 
-  SharedHandle<DHTMessageFactory> factory_;
+  DHTRoutingTable* routingTable_;
+
+  DHTMessageFactory* factory_;
 
-  Logger* logger_;
 public:
   DHTMessageTracker();
 
-  ~DHTMessageTracker();
+  void addMessage(DHTMessage* message, std::chrono::seconds timeout,
+                  std::unique_ptr<DHTMessageCallback> callback =
+                      std::unique_ptr<DHTMessageCallback>{});
 
-  void addMessage(const SharedHandle<DHTMessage>& message,
-                  time_t timeout,
-                  const SharedHandle<DHTMessageCallback>& callback =
-                  SharedHandle<DHTMessageCallback>());
-
-  std::pair<SharedHandle<DHTResponseMessage>, SharedHandle<DHTMessageCallback> >
-  messageArrived(const Dict* dict,
-                 const std::string& ipaddr, uint16_t port);
+  std::pair<std::unique_ptr<DHTResponseMessage>,
+            std::unique_ptr<DHTMessageCallback>>
+  messageArrived(const Dict* dict, const std::string& ipaddr, uint16_t port);
 
   void handleTimeout();
 
-  SharedHandle<DHTMessageTrackerEntry> getEntryFor
-  (const SharedHandle<DHTMessage>& message) const;
+  // Made public so that unnamed functor can access this
+  void handleTimeoutEntry(DHTMessageTrackerEntry* entry);
+
+  // // For unittest only
+  const DHTMessageTrackerEntry* getEntryFor(const DHTMessage* message) const;
 
   size_t countEntry() const;
 
-  void setRoutingTable(const SharedHandle<DHTRoutingTable>& routingTable);
+  void setRoutingTable(DHTRoutingTable* routingTable);
 
-  void setMessageFactory(const SharedHandle<DHTMessageFactory>& factory);
+  void setMessageFactory(DHTMessageFactory* factory);
 };
 
 } // namespace aria2
 
-#endif // _D_DHT_MESSAGE_TRACKER_H_
+#endif // D_DHT_MESSAGE_TRACKER_H
