@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DEFAULT_DISK_WRITER_FACTORY_H_
-#define _D_DEFAULT_DISK_WRITER_FACTORY_H_
+#ifndef D_DEFAULT_DISK_WRITER_FACTORY_H
+#define D_DEFAULT_DISK_WRITER_FACTORY_H
 
 #include "DiskWriterFactory.h"
 
@@ -41,14 +41,12 @@ namespace aria2 {
 
 class DiskWriter;
 
-class DefaultDiskWriterFactory:public DiskWriterFactory
-{
+class DefaultDiskWriterFactory : public DiskWriterFactory {
 public:
-  virtual SharedHandle<DiskWriter> newDiskWriter(const std::string& filename);
+  virtual std::unique_ptr<DiskWriter>
+  newDiskWriter(const std::string& filename) CXX11_OVERRIDE;
 };
 
-typedef SharedHandle<DefaultDiskWriterFactory> DefaultDiskWriterFactoryHandle;
-
 } // namespace aria2
 
-#endif // _D_DEFAULT_DISK_WRITER_FACTORY_H_
+#endif // D_DEFAULT_DISK_WRITER_FACTORY_H
