@@ -39,6 +39,7 @@
 
 #include <string>
 #include <vector>
+#include <memory>
 
 #include "TimeA2.h"
 
@@ -46,13 +47,17 @@ namespace aria2 {
 
 class FileEntry;
 class FileAllocationIterator;
+class WrDiskCacheEntry;
+class OpenedFileCounter;
 
-class DiskAdaptor:public BinaryStream {
-private:
-  std::vector<SharedHandle<FileEntry> > fileEntries_;
-
-  bool fallocate_;
+class DiskAdaptor : public BinaryStream {
 public:
+  enum FileAllocationMethod {
+    FILE_ALLOC_ADAPTIVE,
+    FILE_ALLOC_FALLOC,
+    FILE_ALLOC_TRUNC
+  };
+
   DiskAdaptor();
   virtual ~DiskAdaptor();
 
@@ -66,20 +71,20 @@ public:
 
   virtual bool fileExists() = 0;
 
-  virtual uint64_t size() = 0;
+  virtual int64_t size() = 0;
 
-  template<typename InputIterator>
+  template <typename InputIterator>
   void setFileEntries(InputIterator first, InputIterator last)
   {
     fileEntries_.assign(first, last);
   }
 
-  const std::vector<SharedHandle<FileEntry> >& getFileEntries() const
+  const std::vector<std::shared_ptr<FileEntry>>& getFileEntries() const
   {
     return fileEntries_;
   }
 
-  virtual SharedHandle<FileAllocationIterator> fileAllocationIterator() = 0;
+  virtual std::unique_ptr<FileAllocationIterator> fileAllocationIterator() = 0;
 
   virtual void enableReadOnly() {}
 
@@ -87,6 +92,10 @@ public:
 
   virtual bool isReadOnlyEnabled() const { return false; }
 
+  // Enables mmap feature. Some derived classes may require that files
+  // have been opened before this method call.
+  virtual void enableMmap() {}
+
   // Assumed each file length is stored in fileEntries or DiskAdaptor knows it.
   // If each actual file's length is larger than that, truncate file to that
   // length.
@@ -98,24 +107,44 @@ public:
   // successfully changed.
   virtual size_t utime(const Time& actime, const Time& modtime) = 0;
 
-  void enableFallocate()
+  // Just like readData(), but drop cache after read.
+  virtual ssize_t readDataDropCache(unsigned char* data, size_t len,
+                                    int64_t offset) = 0;
+
+  // Writes cached data to the underlying disk.
+  virtual void writeCache(const WrDiskCacheEntry* entry) = 0;
+
+  void setFileAllocationMethod(FileAllocationMethod method)
   {
-    fallocate_ = true;
+    fileAllocationMethod_ = method;
   }
 
-  void disableFallocate()
+  int getFileAllocationMethod() const { return fileAllocationMethod_; }
+
+  // Closes at most |numClose| files if possible. This method is used to
+  // ensure that global number of open file stays under certain limit.
+  // Returns the number of closed files.
+  virtual size_t tryCloseFile(size_t numClose) { return 0; }
+
+  void
+  setOpenedFileCounter(std::shared_ptr<OpenedFileCounter> openedFileCounter)
   {
-    fallocate_ = false;
+    openedFileCounter_ = std::move(openedFileCounter);
   }
 
-  bool doesFallocate() const
+  const std::shared_ptr<OpenedFileCounter>& getOpenedFileCounter() const
   {
-    return fallocate_;
+    return openedFileCounter_;
   }
+
+private:
+  std::vector<std::shared_ptr<FileEntry>> fileEntries_;
+
+  FileAllocationMethod fileAllocationMethod_;
+
+  std::shared_ptr<OpenedFileCounter> openedFileCounter_;
 };
 
-typedef SharedHandle<DiskAdaptor> DiskAdaptorHandle;
-
 } // namespace aria2
 
 #endif // D_DISK_ADAPTOR_H
