@@ -50,11 +50,12 @@ namespace aria2 {
 class File {
 private:
   std::string name_;
-  
+
   /**
    * Returns the return value of stat(...)
    */
   int fillStat(a2_struct_stat& fstat);
+
 public:
   File(const std::string& name);
 
@@ -69,6 +70,13 @@ public:
    */
   bool exists();
 
+  /**
+   * Tests whether the file or directory denoted by name exists.  If
+   * file does not exist, or file status could not be retrieved, this
+   * function stores error message to |err|.
+   */
+  bool exists(std::string& err);
+
   /**
    * Tests whether the file denoted by name is a regular file.
    */
@@ -94,7 +102,7 @@ public:
    */
   bool mkdirs();
 
-  uint64_t size();
+  int64_t size();
 
   mode_t mode();
 
@@ -102,10 +110,7 @@ public:
 
   std::string getDirname() const;
 
-  const std::string& getPath() const
-  {
-    return name_;
-  }
+  const std::string& getPath() const { return name_; }
 
   static bool isDir(const std::string& filename);
 
@@ -119,8 +124,8 @@ public:
   // directory cannot be retrieved or its length is larger than 2048,
   // returns ".".
   static std::string getCurrentDir();
-  // Returns possible path separators for the underlining platform.
-  static const std::string& getPathSeparators();
+  // Returns possible path separators for the underlying platform.
+  static const char* getPathSeparators();
 };
 
 } // namespace aria2
