@@ -37,29 +37,27 @@
 #include "Request.h"
 #include "SocketCore.h"
 #include "SocketRecvBuffer.h"
+#include "a2functional.h"
 
 namespace aria2 {
 
-HttpProxyRequestCommand::HttpProxyRequestCommand
-(cuid_t cuid,
- const SharedHandle<Request>& req,
- const SharedHandle<FileEntry>& fileEntry,
- RequestGroup* requestGroup,
- DownloadEngine* e,
- const SharedHandle<Request>& proxyRequest,
- const SharedHandle<SocketCore>& s)
-  :
-  AbstractProxyRequestCommand(cuid, req, fileEntry, requestGroup, e,
-                              proxyRequest, s)
-{}
-
-HttpProxyRequestCommand::~HttpProxyRequestCommand() {}
-
-Command* HttpProxyRequestCommand::getNextCommand()
+HttpProxyRequestCommand::HttpProxyRequestCommand(
+    cuid_t cuid, const std::shared_ptr<Request>& req,
+    const std::shared_ptr<FileEntry>& fileEntry, RequestGroup* requestGroup,
+    DownloadEngine* e, const std::shared_ptr<Request>& proxyRequest,
+    const std::shared_ptr<SocketCore>& s)
+    : AbstractProxyRequestCommand(cuid, req, fileEntry, requestGroup, e,
+                                  proxyRequest, s)
 {
-  return new HttpProxyResponseCommand
-    (getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
-     getHttpConnection(), getDownloadEngine(), getSocket());
+}
+
+HttpProxyRequestCommand::~HttpProxyRequestCommand() = default;
+
+std::unique_ptr<Command> HttpProxyRequestCommand::getNextCommand()
+{
+  return make_unique<HttpProxyResponseCommand>(
+      getCuid(), getRequest(), getFileEntry(), getRequestGroup(),
+      getHttpConnection(), getDownloadEngine(), getSocket());
 }
 
 } // namespace aria2
