@@ -32,23 +32,23 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_HTTP_REQUEST_H_
-#define _D_HTTP_REQUEST_H_
+#ifndef D_HTTP_REQUEST_H
+#define D_HTTP_REQUEST_H
 
 #include "common.h"
 
 #include <cassert>
 #include <string>
 #include <vector>
+#include <memory>
 
-#include "SharedHandle.h"
-#include "Request.h"
 #include "FileEntry.h"
 
 namespace aria2 {
 
+class Request;
 class Segment;
-class Range;
+struct Range;
 class Option;
 class CookieStorage;
 class AuthConfigFactory;
@@ -56,126 +56,96 @@ class AuthConfig;
 
 class HttpRequest {
 private:
-  
   static const std::string USER_AGENT;
 
-  SharedHandle<Request> request_;
+  std::shared_ptr<Request> request_;
 
-  SharedHandle<FileEntry> fileEntry_;
+  std::shared_ptr<FileEntry> fileEntry_;
 
-  SharedHandle<Segment> segment_;
+  std::shared_ptr<Segment> segment_;
 
-  bool contentEncodingEnabled_;
+  std::shared_ptr<Request> proxyRequest_;
 
-  std::string userAgent_;
+  std::unique_ptr<AuthConfig> authConfig_;
 
-  std::vector<std::string> headers_;
+  CookieStorage* cookieStorage_;
 
-  std::vector<std::string> acceptTypes_;
-
-  SharedHandle<CookieStorage> cookieStorage_;
-
-  SharedHandle<AuthConfigFactory> authConfigFactory_;
+  AuthConfigFactory* authConfigFactory_;
 
   const Option* option_;
 
-  SharedHandle<AuthConfig> authConfig_;
+  // Historically, aria2 did not specify end byte marker unless http
+  // pipelining is enabled. Sometimes end byte is known because the
+  // segment/piece ahead of this request was already acquired. In this
+  // case, specifying end byte enables to reuse connection. To achieve
+  // this, if endOffsetOverride_ is more than 0, its value - 1 is used
+  // as an end byte. Please note that FTP protocol cannot specify end
+  // bytes and it is also true if it is used via HTTP proxy.
+  int64_t endOffsetOverride_;
 
-  SharedHandle<Request> proxyRequest_;
+  std::vector<std::string> headers_;
+
+  std::string userAgent_;
+
+  std::string ifModSinceHeader_;
+
+  bool contentEncodingEnabled_;
+
+  // If true, metalink content types are sent in Accept header field.
+  bool acceptMetalink_;
 
   bool noCache_;
 
   bool acceptGzip_;
 
-  off_t endOffsetOverride_;
-
-  std::string ifModSinceHeader_;
+  // Don't send Want-Digest header field
+  bool noWantDigest_;
 
   std::pair<std::string, std::string> getProxyAuthString() const;
+
 public:
   HttpRequest();
+  ~HttpRequest();
 
-  const SharedHandle<Segment>& getSegment() const
-  {
-    return segment_;
-  }
+  const std::shared_ptr<Segment>& getSegment() const { return segment_; }
 
-  void setSegment(const SharedHandle<Segment>& segment);
+  void setSegment(std::shared_ptr<Segment> segment);
 
-  void setRequest(const SharedHandle<Request>& request);
+  void setRequest(std::shared_ptr<Request> request);
 
-  uint64_t getEntityLength() const
-  {
-    assert(!fileEntry_.isNull());
-    return fileEntry_->getLength();
-  }
+  int64_t getEntityLength() const;
 
-  const std::string& getHost() const
-  {
-    return request_->getHost();
-  }
+  const std::string& getHost() const;
 
-  uint16_t getPort() const
-  {
-    return request_->getPort();
-  }
+  uint16_t getPort() const;
 
-  const std::string& getMethod() const
-  {
-    return request_->getMethod();
-  }
+  const std::string& getMethod() const;
 
-  const std::string& getProtocol() const
-  {
-    return request_->getProtocol();
-  }
+  const std::string& getProtocol() const;
 
-  const std::string& getCurrentURI() const
-  {
-    return request_->getCurrentUri();
-  }
-  
-  const std::string& getDir() const
-  {
-    return request_->getDir();
-  }
+  const std::string& getCurrentURI() const;
 
-  const std::string& getFile() const
-  {
-    return request_->getFile();
-  }
+  const std::string& getDir() const;
 
-  const std::string& getQuery() const
-  {
-    return request_->getQuery();
-  }
+  const std::string& getFile() const;
 
-  const std::string& getPreviousURI() const
-  {
-    return request_->getPreviousUri();
-  }
+  const std::string& getQuery() const;
 
-  std::string getURIHost() const
-  {
-    return request_->getURIHost();
-  }
+  std::string getURIHost() const;
 
-  SharedHandle<Range> getRange() const;
+  Range getRange() const;
 
   /**
    * Inspects whether the specified response range is satisfiable
    * with request range.
    */
-  bool isRangeSatisfied(const SharedHandle<Range>& range) const;
+  bool isRangeSatisfied(const Range& range) const;
 
-  const SharedHandle<Request>& getRequest() const
-  {
-    return request_;
-  }
+  const std::shared_ptr<Request>& getRequest() const { return request_; }
 
-  off_t getStartByte() const;
+  int64_t getStartByte() const;
 
-  off_t getEndByte() const;
+  int64_t getEndByte() const;
 
   /**
    * Returns string representation of http request.  It usually starts
@@ -196,38 +166,30 @@ public:
 
   void disableContentEncoding();
 
-  void setUserAgent(const std::string& userAgent)
-  {
-    userAgent_ = userAgent;
-  }
-  
+  void setUserAgent(std::string userAgent);
+
   // accepts multiline headers, delimited by LF
   void addHeader(const std::string& headers);
 
+  void clearHeader();
+
   void addAcceptType(const std::string& type);
 
-  template<typename InputIterator>
-  void addAcceptType(InputIterator first, InputIterator last)
-  {
-    acceptTypes_.insert(acceptTypes_.end(), first, last);
-  }
+  void setAcceptMetalink(bool f) { acceptMetalink_ = f; }
 
-  void setCookieStorage(const SharedHandle<CookieStorage>& cookieStorage);
+  void setCookieStorage(CookieStorage* cookieStorage);
 
-  const SharedHandle<CookieStorage>& getCookieStorage() const
-  {
-    return cookieStorage_;
-  }
+  CookieStorage* getCookieStorage() const;
 
-  void setAuthConfigFactory
-  (const SharedHandle<AuthConfigFactory>& factory, const Option* option);
+  void setAuthConfigFactory(AuthConfigFactory* factory);
+  void setOption(const Option* option);
 
   /*
    * To use proxy, pass proxy string to Request::setUri() and set it this
    * object.
    */
-  void setProxyRequest(const SharedHandle<Request>& proxyRequest);
-  
+  void setProxyRequest(std::shared_ptr<Request> proxyRequest);
+
   /*
    * Returns true if non-Null proxy request is set by setProxyRequest().
    * Otherwise, returns false.
@@ -240,59 +202,39 @@ public:
 
   // Returns AuthConfig used in the last invocation of
   // createRequest().
-  const SharedHandle<AuthConfig>& getAuthConfig() const;
+  const std::unique_ptr<AuthConfig>& getAuthConfig() const;
 
-  void setFileEntry(const SharedHandle<FileEntry>& fileEntry)
-  {
-    fileEntry_ = fileEntry;
-  }
+  void setFileEntry(std::shared_ptr<FileEntry> fileEntry);
 
-  const SharedHandle<FileEntry>& getFileEntry() const
-  {
-    return fileEntry_;
-  }
+  const std::shared_ptr<FileEntry>& getFileEntry() const { return fileEntry_; }
 
-  void enableNoCache()
-  {
-    noCache_ = true;
-  }
+  void enableNoCache() { noCache_ = true; }
 
-  void disableNoCache()
-  {
-    noCache_ = false;
-  }
+  void disableNoCache() { noCache_ = false; }
 
-  void enableAcceptGZip()
-  {
-    acceptGzip_ = true;
-  }
+  void enableAcceptGZip() { acceptGzip_ = true; }
 
-  void disableAcceptGZip()
-  {
-    acceptGzip_ = false;
-  }
+  void disableAcceptGZip() { acceptGzip_ = false; }
 
-  bool acceptGZip() const
-  {
-    return acceptGzip_;
-  }
+  bool acceptGZip() const { return acceptGzip_; }
 
-  void setEndOffsetOverride(off_t offset)
-  {
-    endOffsetOverride_ = offset;
-  }
+  void setEndOffsetOverride(int64_t offset) { endOffsetOverride_ = offset; }
 
-  void setIfModifiedSinceHeader(const std::string& hd)
-  {
-    ifModSinceHeader_ = hd;
-  }
+  void setIfModifiedSinceHeader(std::string value);
 
   const std::string& getIfModifiedSinceHeader() const
   {
     return ifModSinceHeader_;
   }
+
+  // Returns true if request is conditional:more specifically, the
+  // request is considered to be conditional if the client sent
+  // "If-Modified-Since" or "If-None-Match" request-header field.
+  bool conditionalRequest() const;
+
+  void setNoWantDigest(bool b) { noWantDigest_ = b; }
 };
 
 } // namespace aria2
 
-#endif // _D_HTTP_REQUEST_H_
+#endif // D_HTTP_REQUEST_H
