@@ -45,39 +45,52 @@ class HttpDownloadCommand;
 class HttpResponse;
 class SocketCore;
 class StreamFilter;
+class Checksum;
 
+// HttpResponseCommand receives HTTP response header from remote
+// server.  Because network I/O is non-blocking, execute() returns
+// false when all response headers are not received.  Subsequent calls
+// of execute() receives remaining response headers and when all
+// headers are received, it examines headers.  If status code is 200
+// or 206 and Range header satisfies requested range, it creates
+// HttpDownloadCommand to receive response entity body.  Otherwise, it
+// creates HttpSkipResponseCommand to receive response entity body and
+// returns true. Handling errors such as 404 or redirect is handled in
+// HttpSkipResponseCommand.
 class HttpResponseCommand : public AbstractCommand {
 private:
-  SharedHandle<HttpConnection> httpConnection_;
+  std::shared_ptr<HttpConnection> httpConnection_;
 
-  bool handleDefaultEncoding(const SharedHandle<HttpResponse>& httpResponse);
-  bool handleOtherEncoding(const SharedHandle<HttpResponse>& httpResponse);
-  bool skipResponseBody(const SharedHandle<HttpResponse>& httpResponse);
+  bool handleDefaultEncoding(std::unique_ptr<HttpResponse> httpResponse);
+  bool handleOtherEncoding(std::unique_ptr<HttpResponse> httpResponse);
+  bool skipResponseBody(std::unique_ptr<HttpResponse> httpResponse);
 
-  HttpDownloadCommand*
-  createHttpDownloadCommand
-  (const SharedHandle<HttpResponse>& httpResponse,
-   const SharedHandle<StreamFilter>& streamFilter);
+  std::unique_ptr<HttpDownloadCommand>
+  createHttpDownloadCommand(std::unique_ptr<HttpResponse> httpResponse,
+                            std::unique_ptr<StreamFilter> streamFilter);
 
   void updateLastModifiedTime(const Time& lastModified);
 
   void poolConnection();
 
   void onDryRunFileFound();
-protected:
-  bool executeInternal();
+  // Returns true if dctx and checksum has same hash type and hash
+  // value.  If they have same hash type but different hash value,
+  // throws exception.  Otherwise returns false.
+  bool checkChecksum(const std::shared_ptr<DownloadContext>& dctx,
+                     const Checksum& checksum);
 
-  bool shouldInflateContentEncoding
-  (const SharedHandle<HttpResponse>& httpResponse);
+protected:
+  bool executeInternal() CXX11_OVERRIDE;
+
+  bool shouldInflateContentEncoding(HttpResponse* httpResponse);
 
 public:
-  HttpResponseCommand(cuid_t cuid,
-                      const SharedHandle<Request>& req,
-                      const SharedHandle<FileEntry>& fileEntry,
+  HttpResponseCommand(cuid_t cuid, const std::shared_ptr<Request>& req,
+                      const std::shared_ptr<FileEntry>& fileEntry,
                       RequestGroup* requestGroup,
-                      const SharedHandle<HttpConnection>& httpConnection,
-                      DownloadEngine* e,
-                      const SharedHandle<SocketCore>& s);
+                      const std::shared_ptr<HttpConnection>& httpConnection,
+                      DownloadEngine* e, const std::shared_ptr<SocketCore>& s);
   ~HttpResponseCommand();
 };
 
