@@ -32,11 +32,11 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_ITERATABLE_VALIDATOR_H_
-#define _D_ITERATABLE_VALIDATOR_H_
+#ifndef D_ITERATABLE_VALIDATOR_H
+#define D_ITERATABLE_VALIDATOR_H
 
 #include "common.h"
-#include "SharedHandle.h"
+
 #include <unistd.h>
 
 namespace aria2 {
@@ -49,10 +49,9 @@ namespace aria2 {
  * The progress information is available using getCurrentOffset() and
  * getTotalLength().
  */
-class IteratableValidator
-{
+class IteratableValidator {
 public:
-  virtual ~IteratableValidator() {}
+  virtual ~IteratableValidator() = default;
 
   virtual void init() = 0;
 
@@ -60,13 +59,11 @@ public:
 
   virtual bool finished() const = 0;
 
-  virtual off_t getCurrentOffset() const = 0;
+  virtual int64_t getCurrentOffset() const = 0;
 
-  virtual uint64_t getTotalLength() const = 0;
+  virtual int64_t getTotalLength() const = 0;
 };
 
-typedef SharedHandle<IteratableValidator> IteratableValidatorHandle;
-
 } // namespace aria2
 
-#endif // _D_ITERATABLE_VALIDATOR_H_
+#endif // D_ITERATABLE_VALIDATOR_H
