@@ -32,50 +32,33 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_LIBSSL_ARC4_ENCRYPTOR_H_
-#define _D_LIBSSL_ARC4_ENCRYPTOR_H_
+#ifndef D_LIBSSL_ARC4_ENCRYPTOR_H
+#define D_LIBSSL_ARC4_ENCRYPTOR_H
 
 #include "common.h"
 
-#include <openssl/evp.h>
-#include <openssl/err.h>
+#include <cstdlib>
 
-#include "DlAbortEx.h"
-#include "LibsslARC4Context.h"
-#include "StringFormat.h"
+#include <openssl/rc4.h>
 
 namespace aria2 {
 
 class ARC4Encryptor {
 private:
-  LibsslARC4Context ctx_;
+  RC4_KEY key_;
 
-  void handleError() const
-  {
-    throw DL_ABORT_EX
-      (StringFormat("Exception in libssl routine(ARC4Encryptor class): %s",
-                    ERR_error_string(ERR_get_error(), 0)).str());
-  }
 public:
-  ARC4Encryptor() {}
+  ARC4Encryptor();
 
-  ~ARC4Encryptor() {}
+  ~ARC4Encryptor();
 
-  void init(const unsigned char* key, size_t keyLength)
-  {
-    ctx_.init(key, keyLength, 1);
-  }
+  void init(const unsigned char* key, size_t keyLength);
 
-  void encrypt(unsigned char* out, size_t outLength,
-               const unsigned char* in, size_t inLength)
-  {
-    int soutLength = outLength;
-    if(!EVP_CipherUpdate(ctx_.getCipherContext(), out, &soutLength, in, inLength)) {
-      handleError();
-    }
-  }
+  // Encrypts data in in buffer to out buffer. in and out can be the
+  // same buffer.
+  void encrypt(size_t len, unsigned char* out, const unsigned char* in);
 };
 
 } // namespace aria2
 
-#endif // _D_LIBSSL_ARC4_ENCRYPTOR_H_
+#endif // D_LIBSSL_ARC4_ENCRYPTOR_H
