@@ -32,33 +32,33 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_METALINK_PARSER_STATE_IMPL_H_
-#define _D_METALINK_PARSER_STATE_IMPL_H_
+#ifndef D_METALINK_PARSER_STATE_IMPL_H
+#define D_METALINK_PARSER_STATE_IMPL_H
 
 #include "MetalinkParserState.h"
 
 namespace aria2 {
 
-class SkipTagMetalinkParserState:public MetalinkParserState
-{
+std::vector<XmlAttr>::const_iterator findAttr(const std::vector<XmlAttr>& attrs,
+                                              const char* localname,
+                                              const char* nsUri);
+
+class SkipTagMetalinkParserState : public MetalinkParserState {
 public:
-  virtual void beginElement(MetalinkParserStateMachine* stm,
-                            const std::string& localname,
-                            const std::string& prefix,
-                            const std::string& nsUri,
-                            const std::vector<XmlAttr>& attrs);
+  virtual void beginElement(MetalinkParserStateMachine* psm,
+                            const char* localname, const char* prefix,
+                            const char* nsUri,
+                            const std::vector<XmlAttr>& attrs) CXX11_OVERRIDE;
 };
 
-class InitialMetalinkParserState:public MetalinkParserState
-{
+class InitialMetalinkParserState : public MetalinkParserState {
 public:
-  virtual void beginElement(MetalinkParserStateMachine* stm,
-                            const std::string& localname,
-                            const std::string& prefix,
-                            const std::string& nsUri,
-                            const std::vector<XmlAttr>& attrs);
+  virtual void beginElement(MetalinkParserStateMachine* psm,
+                            const char* localname, const char* prefix,
+                            const char* nsUri,
+                            const std::vector<XmlAttr>& attrs) CXX11_OVERRIDE;
 };
 
 } // namespace aria2
 
-#endif // _D_METALINK_PARSER_STATE_IMPL_H_
+#endif // D_METALINK_PARSER_STATE_IMPL_H
