@@ -45,12 +45,14 @@ class DiskWriter;
 
 class DiskWriterEntry {
 private:
-  SharedHandle<FileEntry> fileEntry_;
-  SharedHandle<DiskWriter> diskWriter_;
+  std::shared_ptr<FileEntry> fileEntry_;
+  std::unique_ptr<DiskWriter> diskWriter_;
   bool open_;
   bool needsFileAllocation_;
+  bool needsDiskWriter_;
+
 public:
-  DiskWriterEntry(const SharedHandle<FileEntry>& fileEntry);
+  DiskWriterEntry(const std::shared_ptr<FileEntry>& fileEntry);
 
   const std::string& getFilePath() const;
 
@@ -62,59 +64,51 @@ public:
 
   void closeFile();
 
-  bool isOpen() const
-  {
-    return open_;
-  }
+  bool isOpen() const { return open_; }
 
   bool fileExists();
 
   int64_t size() const;
 
-  const SharedHandle<FileEntry>& getFileEntry() const
-  {
-    return fileEntry_;
-  }
+  const std::shared_ptr<FileEntry>& getFileEntry() const { return fileEntry_; }
 
-  void setDiskWriter(const SharedHandle<DiskWriter>& diskWriter);
+  void setDiskWriter(std::unique_ptr<DiskWriter> diskWriter);
 
-  const SharedHandle<DiskWriter>& getDiskWriter() const
+  const std::unique_ptr<DiskWriter>& getDiskWriter() const
   {
     return diskWriter_;
   }
 
   bool operator<(const DiskWriterEntry& entry) const;
 
-  bool needsFileAllocation() const
-  {
-    return needsFileAllocation_;
-  }
+  bool needsFileAllocation() const { return needsFileAllocation_; }
 
-  void needsFileAllocation(bool f)
-  {
-    needsFileAllocation_ = f;
-  }
+  void needsFileAllocation(bool f) { needsFileAllocation_ = f; }
 
+  bool needsDiskWriter() const { return needsDiskWriter_; }
+
+  void needsDiskWriter(bool f) { needsDiskWriter_ = f; }
 };
 
-typedef std::vector<SharedHandle<DiskWriterEntry> > DiskWriterEntries;
+typedef std::vector<std::unique_ptr<DiskWriterEntry>> DiskWriterEntries;
 
 class MultiDiskAdaptor : public DiskAdaptor {
   friend class MultiFileAllocationIterator;
+
 private:
   int32_t pieceLength_;
   DiskWriterEntries diskWriterEntries_;
 
-  std::vector<SharedHandle<DiskWriterEntry> > openedDiskWriterEntries_;
-
-  int maxOpenFiles_;
+  std::vector<DiskWriterEntry*> openedDiskWriterEntries_;
 
   bool readOnly_;
 
   void resetDiskWriterEntries();
 
-  void openIfNot(const SharedHandle<DiskWriterEntry>& entry,
-                 void (DiskWriterEntry::*f)());
+  void openIfNot(DiskWriterEntry* entry, void (DiskWriterEntry::*f)());
+
+  ssize_t readData(unsigned char* data, size_t len, int64_t offset,
+                   bool dropCache);
 
   static const int DEFAULT_MAX_OPEN_FILES = 100;
 
@@ -122,56 +116,56 @@ public:
   MultiDiskAdaptor();
   ~MultiDiskAdaptor();
 
-  virtual void initAndOpenFile();
+  virtual void initAndOpenFile() CXX11_OVERRIDE;
 
-  virtual void openFile();
+  virtual void openFile() CXX11_OVERRIDE;
 
-  virtual void openExistingFile();
+  virtual void openExistingFile() CXX11_OVERRIDE;
 
-  virtual void closeFile();
+  virtual void closeFile() CXX11_OVERRIDE;
 
   virtual void writeData(const unsigned char* data, size_t len,
-                         int64_t offset);
+                         int64_t offset) CXX11_OVERRIDE;
 
-  virtual ssize_t readData(unsigned char* data, size_t len, int64_t offset);
+  virtual ssize_t readData(unsigned char* data, size_t len,
+                           int64_t offset) CXX11_OVERRIDE;
 
-  virtual bool fileExists();
+  virtual ssize_t readDataDropCache(unsigned char* data, size_t len,
+                                    int64_t offset) CXX11_OVERRIDE;
 
-  virtual int64_t size();
+  virtual void writeCache(const WrDiskCacheEntry* entry) CXX11_OVERRIDE;
 
-  virtual SharedHandle<FileAllocationIterator> fileAllocationIterator();
+  virtual bool fileExists() CXX11_OVERRIDE;
 
-  virtual void enableReadOnly();
+  virtual int64_t size() CXX11_OVERRIDE;
 
-  virtual void disableReadOnly();
+  virtual std::unique_ptr<FileAllocationIterator>
+  fileAllocationIterator() CXX11_OVERRIDE;
 
-  virtual bool isReadOnlyEnabled() const { return readOnly_; }
+  virtual void enableReadOnly() CXX11_OVERRIDE;
+
+  virtual void disableReadOnly() CXX11_OVERRIDE;
+
+  virtual bool isReadOnlyEnabled() const CXX11_OVERRIDE { return readOnly_; }
 
   // Enables mmap feature. This method must be called after files are
   // opened.
-  virtual void enableMmap();
+  virtual void enableMmap() CXX11_OVERRIDE;
 
-  void setPieceLength(int32_t pieceLength)
-  {
-    pieceLength_ = pieceLength;
-  }
+  void setPieceLength(int32_t pieceLength) { pieceLength_ = pieceLength; }
 
-  int32_t getPieceLength() const {
-    return pieceLength_;
-  }
+  int32_t getPieceLength() const { return pieceLength_; }
 
-  virtual void cutTrailingGarbage();
+  virtual void cutTrailingGarbage() CXX11_OVERRIDE;
 
-  void setMaxOpenFiles(int maxOpenFiles);
+  virtual size_t utime(const Time& actime, const Time& modtime) CXX11_OVERRIDE;
 
-  virtual size_t utime(const Time& actime, const Time& modtime);
-
-  const std::vector<SharedHandle<DiskWriterEntry> >&
-  getDiskWriterEntries() const
+  const DiskWriterEntries& getDiskWriterEntries() const
   {
     return diskWriterEntries_;
   }
 
+  virtual size_t tryCloseFile(size_t numClose) CXX11_OVERRIDE;
 };
 
 } // namespace aria2
