@@ -45,32 +45,29 @@
 
 namespace aria2 {
 
-NameResolver::NameResolver():socktype_(0), family_(AF_UNSPEC) {}
+NameResolver::NameResolver() : socktype_(0), family_(AF_UNSPEC) {}
 
 void NameResolver::resolve(std::vector<std::string>& resolvedAddresses,
                            const std::string& hostname)
 {
   struct addrinfo* res;
   int s;
-  s = callGetaddrinfo(&res, hostname.c_str(), nullptr, family_, socktype_, 0, 0);
-  if(s) {
-    throw DL_ABORT_EX2(fmt(EX_RESOLVE_HOSTNAME,
-                           hostname.c_str(), gai_strerror(s)),
-                       error_code::NAME_RESOLVE_ERROR);
+  s = callGetaddrinfo(&res, hostname.c_str(), nullptr, family_, socktype_, 0,
+                      0);
+  if (s) {
+    throw DL_ABORT_EX2(
+        fmt(EX_RESOLVE_HOSTNAME, hostname.c_str(), gai_strerror(s)),
+        error_code::NAME_RESOLVE_ERROR);
   }
-  std::unique_ptr<addrinfo, decltype(&freeaddrinfo)> resDeleter
-    (res, freeaddrinfo);
+  std::unique_ptr<addrinfo, decltype(&freeaddrinfo)> resDeleter(res,
+                                                                freeaddrinfo);
   struct addrinfo* rp;
-  for(rp = res; rp; rp = rp->ai_next) {
-    std::pair<std::string, uint16_t> addressPort
-      = util::getNumericNameInfo(rp->ai_addr, rp->ai_addrlen);
-    resolvedAddresses.push_back(addressPort.first);
+  for (rp = res; rp; rp = rp->ai_next) {
+    auto endpoint = util::getNumericNameInfo(rp->ai_addr, rp->ai_addrlen);
+    resolvedAddresses.push_back(endpoint.addr);
   }
 }
 
-void NameResolver::setSocktype(int socktype)
-{
-  socktype_ = socktype;
-}
+void NameResolver::setSocktype(int socktype) { socktype_ = socktype; }
 
 } // namespace aria2
