@@ -42,8 +42,8 @@
 #include <iosfwd>
 #include <functional>
 
-#include "SharedHandle.h"
 #include "console.h"
+#include "prefs.h"
 
 namespace aria2 {
 
@@ -57,11 +57,10 @@ extern const std::string PATH_TO_DIR;
 extern const std::string PATH_TO_COMMAND;
 
 class Option;
-struct Pref;
 
 class OptionHandler {
 public:
-  virtual ~OptionHandler() {}
+  virtual ~OptionHandler() = default;
 
   virtual void parse(Option& option, const std::string& arg) const = 0;
 
@@ -83,13 +82,9 @@ public:
 
   virtual void hide() = 0;
 
-  virtual const Pref* getPref() const = 0;
+  virtual PrefPtr getPref() const = 0;
 
-  enum ARG_TYPE {
-    REQ_ARG,
-    OPT_ARG,
-    NO_ARG
-  };
+  enum ARG_TYPE { REQ_ARG, OPT_ARG, NO_ARG };
 
   virtual ARG_TYPE getArgType() const = 0;
 
