@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * In addition, as a special exception, the copyright holders give
  * permission to link the code of portions of this program with the
@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_PLATFORM_H_
-#define _D_PLATFORM_H_
+#ifndef D_PLATFORM_H
+#define D_PLATFORM_H
 
 #include "common.h"
 
@@ -41,7 +41,7 @@ namespace aria2 {
 
 class Platform {
 private:
-  static bool _initialized;
+  static bool initialized_;
 
 public:
   Platform();
@@ -57,4 +57,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_PLATFORM_H_
+#endif // D_PLATFORM_H
