@@ -32,27 +32,28 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_RAREST_PIECE_SELECTOR_H_
-#define _D_RAREST_PIECE_SELECTOR_H_
+#ifndef D_RAREST_PIECE_SELECTOR_H
+#define D_RAREST_PIECE_SELECTOR_H
 
 #include "PieceSelector.h"
-#include "SharedHandle.h"
+
+#include <memory>
 
 namespace aria2 {
 
 class PieceStatMan;
 
-class RarestPieceSelector:public PieceSelector {
+class RarestPieceSelector : public PieceSelector {
 private:
-  SharedHandle<PieceStatMan> pieceStatMan_;
-public:
-  RarestPieceSelector(const SharedHandle<PieceStatMan>& pieceStatMan);
+  std::shared_ptr<PieceStatMan> pieceStatMan_;
 
-  virtual bool select
-  (size_t& index, const unsigned char* bitfield, size_t nbits) const;
+public:
+  RarestPieceSelector(const std::shared_ptr<PieceStatMan>& pieceStatMan);
+
+  virtual bool select(size_t& index, const unsigned char* bitfield,
+                      size_t nbits) const CXX11_OVERRIDE;
 };
 
 } // namespace aria2
 
-#endif // _D_RAREST_PIECE_SELECTOR_H_
-
+#endif // D_RAREST_PIECE_SELECTOR_H
