@@ -33,9 +33,6 @@
  */
 /* copyright --> */
 #include "Signature.h"
-
-#include <fstream>
-
 #include "File.h"
 #include "util.h"
 
@@ -43,22 +40,13 @@ namespace aria2 {
 
 Signature::Signature() {}
 
-Signature::~Signature() {}
+Signature::~Signature() = default;
 
-void Signature::setType(const std::string& type)
-{
-  type_ = type;
-}
+void Signature::setType(std::string type) { type_ = std::move(type); }
 
-void Signature::setFile(const std::string& file)
-{
-  file_ = file;
-}
+void Signature::setFile(std::string file) { file_ = std::move(file); }
 
-void Signature::setBody(const std::string& body)
-{
-  body_ = body;
-}
+void Signature::setBody(std::string body) { body_ = std::move(body); }
 
 bool Signature::save(const std::string& filepath) const
 {
