@@ -36,39 +36,39 @@
 #include "DownloadEngine.h"
 #include "RequestGroupMan.h"
 #include "Logger.h"
+#include "LogFactory.h"
 #include "message.h"
-#include "FileEntry.h"
-#include "ServerStatMan.h"
-#include "FileAllocationEntry.h"
-#include "CheckIntegrityEntry.h"
+#include "fmt.h"
 
 namespace aria2 {
 
 TimedHaltCommand::TimedHaltCommand(cuid_t cuid, DownloadEngine* e,
-                                   time_t secondsToHalt,
-                                   bool forceHalt):
-  TimeBasedCommand(cuid, e, secondsToHalt, true),
-  forceHalt_(forceHalt) {}
+                                   std::chrono::seconds secondsToHalt,
+                                   bool forceHalt)
+    : TimeBasedCommand(cuid, e, std::move(secondsToHalt), true),
+      forceHalt_(forceHalt)
+{
+}
 
-TimedHaltCommand::~TimedHaltCommand() {}
+TimedHaltCommand::~TimedHaltCommand() = default;
 
 void TimedHaltCommand::preProcess()
 {
-  if(getDownloadEngine()->getRequestGroupMan()->downloadFinished() ||
-     getDownloadEngine()->isHaltRequested()) {
+  if (getDownloadEngine()->getRequestGroupMan()->downloadFinished() ||
+      getDownloadEngine()->isHaltRequested()) {
     enableExit();
   }
 }
 
 void TimedHaltCommand::process()
 {
-  if(!getDownloadEngine()->isHaltRequested()) {
-    getLogger()->notice(MSG_TIME_HAS_PASSED,
-                        static_cast<long int>(getInterval()));
-    if(forceHalt_) {
-      getLogger()->notice("This is emergency shutdown.");
+  if (!getDownloadEngine()->isHaltRequested()) {
+    A2_LOG_NOTICE(
+        fmt(MSG_TIME_HAS_PASSED, static_cast<long int>(getInterval().count())));
+    if (forceHalt_) {
       getDownloadEngine()->requestForceHalt();
-    } else {
+    }
+    else {
       getDownloadEngine()->requestHalt();
     }
     enableExit();
