@@ -2,7 +2,7 @@
 /*
  * aria2 - The high speed download utility
  *
- * Copyright (C) 2006 Tatsuhiro Tsujikawa
+ * Copyright (C) 2012 Tatsuhiro Tsujikawa
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,97 +32,39 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_TRANSFER_STAT_H_
-#define _D_TRANSFER_STAT_H_
+#ifndef D_TRANSFER_STAT_H
+#define D_TRANSFER_STAT_H
 
 #include "common.h"
-#include <stdint.h>
 
 namespace aria2 {
 
-class TransferStat {
-public:
-  unsigned int downloadSpeed;
-  unsigned int uploadSpeed;
-  uint64_t sessionDownloadLength;
-  uint64_t sessionUploadLength;
-  uint64_t allTimeUploadLength;
-
-  void copy(const TransferStat& stat)
+struct TransferStat {
+  TransferStat()
+      : downloadSpeed(0),
+        uploadSpeed(0),
+        sessionDownloadLength(0),
+        sessionUploadLength(0),
+        allTimeUploadLength(0)
   {
-    downloadSpeed = stat.downloadSpeed;
-    uploadSpeed = stat.uploadSpeed;
-    sessionDownloadLength = stat.sessionDownloadLength;
-    sessionUploadLength = stat.sessionUploadLength;
-    allTimeUploadLength = stat.allTimeUploadLength;
   }
-public:
-  TransferStat():downloadSpeed(0), uploadSpeed(0),
-                 sessionDownloadLength(0), sessionUploadLength(0),
-                 allTimeUploadLength(0) {}
-
-  TransferStat(const TransferStat& stat)
-  {
-    copy(stat);
-  }
-
-  TransferStat& operator=(const TransferStat& stat)
-  {
-    if(this != &stat) {
-      copy(stat);
-    }
-    return *this;
-  }
-
-  friend TransferStat operator+(const TransferStat& a, const TransferStat& b);
-
-  friend TransferStat operator-(const TransferStat& a, const TransferStat& b);
 
   TransferStat& operator+=(const TransferStat& stat);
-
   TransferStat& operator-=(const TransferStat& stat);
 
-  unsigned int getDownloadSpeed() const {
-    return downloadSpeed;
-  }
-
-  void setDownloadSpeed(unsigned int s) { downloadSpeed = s; }
-
-  unsigned int getUploadSpeed() const {
-    return uploadSpeed;
-  }
-
-  void setUploadSpeed(unsigned int s) { uploadSpeed = s; }
-
+  int downloadSpeed;
+  int uploadSpeed;
   /**
    * Returns the number of bytes downloaded since the program started.
    * This is not the total number of bytes downloaded.
    */
-  uint64_t getSessionDownloadLength() const {
-    return sessionDownloadLength;
-  }
-
-  void setSessionDownloadLength(uint64_t s) { sessionDownloadLength = s; }
-
+  int64_t sessionDownloadLength;
   /**
    * Returns the number of bytes uploaded since the program started.
    * This is not the total number of bytes uploaded.
    */
-  uint64_t getSessionUploadLength() const {
-    return sessionUploadLength;
-  }
-
-  void setSessionUploadLength(uint64_t s) { sessionUploadLength = s; }
-
-  void setAllTimeUploadLength(uint64_t s)
-  {
-    allTimeUploadLength = s;
-  }
-
-  uint64_t getAllTimeUploadLength() const
-  {
-    return allTimeUploadLength;
-  }
+  int64_t sessionUploadLength;
+  int64_t allTimeUploadLength;
 };
 
 TransferStat operator+(const TransferStat& a, const TransferStat& b);
@@ -131,4 +73,4 @@ TransferStat operator-(const TransferStat& a, const TransferStat& b);
 
 } // namespace aria2
 
-#endif // _D_TRANSFER_STAT_H_
+#endif // D_TRANSFER_STAT_H
