@@ -32,24 +32,24 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_UT_METADATA_REJECT_EXTENSION_MESSAGE_H_
-#define _D_UT_METADATA_REJECT_EXTENSION_MESSAGE_H_
+#ifndef D_UT_METADATA_REJECT_EXTENSION_MESSAGE_H
+#define D_UT_METADATA_REJECT_EXTENSION_MESSAGE_H
 
 #include "UTMetadataExtensionMessage.h"
 
 namespace aria2 {
 
-class UTMetadataRejectExtensionMessage:public UTMetadataExtensionMessage {
+class UTMetadataRejectExtensionMessage : public UTMetadataExtensionMessage {
 public:
   UTMetadataRejectExtensionMessage(uint8_t extensionMessageID);
 
-  virtual std::string getPayload();
+  virtual std::string getPayload() CXX11_OVERRIDE;
 
-  virtual std::string toString() const;
+  virtual std::string toString() const CXX11_OVERRIDE;
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
 
-#endif // _D_UT_METADATA_REJECT_EXTENSION_MESSAGE_H_
+#endif // D_UT_METADATA_REJECT_EXTENSION_MESSAGE_H
