@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _UT_METADATA_REQUEST_TRACKER_H_
-#define _UT_METADATA_REQUEST_TRACKER_H_
+#ifndef D_UT_METADATA_REQUEST_TRACKER_H
+#define D_UT_METADATA_REQUEST_TRACKER_H
 
 #include "common.h"
 
@@ -44,30 +44,26 @@
 
 namespace aria2 {
 
-class Logger;
-
 class UTMetadataRequestTracker {
-private:
+public:
+  // Made public so that unnamed functor can access this
   struct RequestEntry {
     size_t index_;
     Timer dispatchedTime_;
 
-    RequestEntry(size_t index):index_(index) {}
+    RequestEntry(size_t index) : index_(index) {}
 
-    bool elapsed(time_t t) const
+    bool elapsed(const std::chrono::seconds t) const
     {
-      return dispatchedTime_.difference(global::wallclock) >= t;
+      return dispatchedTime_.difference(global::wallclock()) >= t;
     }
 
-    bool operator==(const RequestEntry& e) const
-    {
-      return index_ == e.index_;
-    }
+    bool operator==(const RequestEntry& e) const { return index_ == e.index_; }
   };
 
+private:
   std::vector<RequestEntry> trackedRequests_;
 
-  Logger* logger_;
 public:
   UTMetadataRequestTracker();
 
@@ -87,10 +83,7 @@ public:
   std::vector<size_t> removeTimeoutEntry();
 
   // Returns the number of tracking list.
-  size_t count() const
-  {
-    return trackedRequests_.size();
-  }
+  size_t count() const { return trackedRequests_.size(); }
 
   // Returns the number of additional index this tracker can track.
   size_t avail() const;
@@ -98,4 +91,4 @@ public:
 
 } // namespace aria2
 
-#endif // _UT_METADATA_REQUEST_TRACKER_H_
+#endif // D_UT_METADATA_REQUEST_TRACKER_H
