@@ -48,15 +48,11 @@ namespace rpc {
 
 class XmlRpcRequestParserController {
 private:
-
   struct StateFrame {
-    SharedHandle<ValueBase> value_;
+    std::unique_ptr<ValueBase> value_;
     std::string name_;
 
-    bool validMember() const
-    {
-      return value_ && !name_.empty();
-    }
+    bool validMember() const { return value_ && !name_.empty(); }
 
     void reset()
     {
@@ -70,6 +66,7 @@ private:
   StateFrame currentFrame_;
 
   std::string methodName_;
+
 public:
   void pushFrame();
 
@@ -80,17 +77,16 @@ public:
   // Pops StateFrame p from frameStack_ and add currentFrame_.value_
   // to p and currentFrame_ = p;
   void popArrayFrame();
-  
-  void setCurrentFrameValue(const SharedHandle<ValueBase>& value);
 
-  void setCurrentFrameName(const std::string& name);
+  void setCurrentFrameValue(std::unique_ptr<ValueBase> value);
 
-  const SharedHandle<ValueBase>& getCurrentFrameValue() const;
+  void setCurrentFrameName(std::string name);
 
-  void setMethodName(const std::string& methodName)
-  {
-    methodName_ = methodName;
-  }
+  const std::unique_ptr<ValueBase>& getCurrentFrameValue() const;
+
+  std::unique_ptr<ValueBase> popCurrentFrameValue();
+
+  void setMethodName(std::string methodName);
 
   const std::string& getMethodName() const { return methodName_; }
 
