@@ -4,34 +4,36 @@
 
 namespace aria2 {
 
-class BtKeepAliveMessageTest:public CppUnit::TestFixture {
+class BtKeepAliveMessageTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(BtKeepAliveMessageTest);
-  CPPUNIT_TEST(testGetMessage);
+  CPPUNIT_TEST(testCreateMessage);
   CPPUNIT_TEST(testToString);
   CPPUNIT_TEST_SUITE_END();
+
 private:
-
 public:
-  void setUp() {
-  }
+  void setUp() {}
 
-  void testGetMessage();
+  void testCreateMessage();
   void testToString();
 };
 
 CPPUNIT_TEST_SUITE_REGISTRATION(BtKeepAliveMessageTest);
 
-void BtKeepAliveMessageTest::testGetMessage() {
-  char msg[4];
-  memset(msg, 0, sizeof(msg));
+void BtKeepAliveMessageTest::testCreateMessage()
+{
+  char data[4];
+  memset(data, 0, sizeof(data));
   BtKeepAliveMessage message;
   CPPUNIT_ASSERT_EQUAL((uint8_t)99, message.getId());
-  CPPUNIT_ASSERT_EQUAL((size_t)4, message.getMessageLength());
-  CPPUNIT_ASSERT(memcmp(msg, message.getMessage(), 4) == 0);
+  auto rawmsg = message.createMessage();
+  CPPUNIT_ASSERT_EQUAL((size_t)4, rawmsg.size());
+  CPPUNIT_ASSERT(std::equal(std::begin(rawmsg), std::end(rawmsg), data));
 }
 
-void BtKeepAliveMessageTest::testToString() {
+void BtKeepAliveMessageTest::testToString()
+{
   BtKeepAliveMessage msg;
   CPPUNIT_ASSERT_EQUAL(std::string("keep alive"), msg.toString());
 }
