@@ -9,31 +9,20 @@ namespace aria2 {
 class FixedNumberRandomizer : public Randomizer {
 private:
   int32_t fixedNumber;
+
 public:
-  FixedNumberRandomizer():fixedNumber(0) {}
+  FixedNumberRandomizer() : fixedNumber(0) {}
 
   virtual ~FixedNumberRandomizer() {}
 
-  virtual long int getRandomNumber() CXX11_OVERRIDE {
-    return fixedNumber;
-  }
-
-  virtual long int getMaxRandomNumber() CXX11_OVERRIDE {
-    return RAND_MAX;
-  }
-
   virtual long int getRandomNumber(long int to) CXX11_OVERRIDE
   {
-    return getRandomNumber();
-  }
-
-  void setFixedNumber(int32_t num) {
-    this->fixedNumber = num;
-  }
-
-  int32_t getFixedNumber() const {
     return fixedNumber;
   }
+
+  void setFixedNumber(int32_t num) { this->fixedNumber = num; }
+
+  int32_t getFixedNumber() const { return fixedNumber; }
 };
 
 } // namespace aria2
