@@ -1,8 +1,11 @@
 #include "NetrcAuthResolver.h"
+
+#include <cppunit/extensions/HelperMacros.h>
+
 #include "prefs.h"
 #include "Netrc.h"
 #include "AuthConfig.h"
-#include <cppunit/extensions/HelperMacros.h>
+#include "a2functional.h"
 
 namespace aria2 {
 
@@ -13,24 +16,23 @@ class NetrcAuthResolverTest : public CppUnit::TestFixture {
   CPPUNIT_TEST(testResolveAuthConfig_with_userDefined);
   CPPUNIT_TEST(testResolveAuthConfig_ignoreDefault);
   CPPUNIT_TEST_SUITE_END();
+
 private:
-  SharedHandle<Netrc> netrc_;
-  //SharedHandle<Option> _option;
-  SharedHandle<NetrcAuthResolver> resolver_;
+  std::unique_ptr<Netrc> netrc_;
+  std::unique_ptr<NetrcAuthResolver> resolver_;
+
 public:
   void setUp()
   {
     netrc_.reset(new Netrc());
-    netrc_->addAuthenticator
-      (SharedHandle<Authenticator>(new Authenticator("localhost", "name", "passwd", "account")));
-    netrc_->addAuthenticator
-      (SharedHandle<Authenticator>(new DefaultAuthenticator("default", "defaultpasswd", "defaultaccount")));
+    netrc_->addAuthenticator(
+        make_unique<Authenticator>("localhost", "name", "passwd", "account"));
+    netrc_->addAuthenticator(make_unique<DefaultAuthenticator>(
+        "default", "defaultpasswd", "defaultaccount"));
 
-    //_option = new Option();
     resolver_.reset(new NetrcAuthResolver());
-    resolver_->setNetrc(netrc_);
-    resolver_->setDefaultAuthConfig
-      (SharedHandle<AuthConfig>(new AuthConfig("foo", "bar")));
+    resolver_->setNetrc(netrc_.get());
+    resolver_->setDefaultCred("foo", "bar");
   }
 
   void testResolveAuthConfig_without_userDefined();
@@ -38,49 +40,49 @@ public:
   void testResolveAuthConfig_ignoreDefault();
 };
 
-
-CPPUNIT_TEST_SUITE_REGISTRATION( NetrcAuthResolverTest );
+CPPUNIT_TEST_SUITE_REGISTRATION(NetrcAuthResolverTest);
 
 void NetrcAuthResolverTest::testResolveAuthConfig_without_userDefined()
 {
-  SharedHandle<AuthConfig> authConfig = resolver_->resolveAuthConfig("localhost");
+  auto authConfig = resolver_->resolveAuthConfig("localhost");
   CPPUNIT_ASSERT_EQUAL(std::string("name:passwd"), authConfig->getAuthText());
 
   authConfig = resolver_->resolveAuthConfig("mymachine");
-  CPPUNIT_ASSERT_EQUAL(std::string("default:defaultpasswd"), authConfig->getAuthText());
+  CPPUNIT_ASSERT_EQUAL(std::string("default:defaultpasswd"),
+                       authConfig->getAuthText());
 
-  resolver_->setNetrc(SharedHandle<Netrc>());
+  resolver_->setNetrc(nullptr);
   authConfig = resolver_->resolveAuthConfig("localhost");
   CPPUNIT_ASSERT_EQUAL(std::string("foo:bar"), authConfig->getAuthText());
-
 }
 
 void NetrcAuthResolverTest::testResolveAuthConfig_with_userDefined()
 {
-  resolver_->setUserDefinedAuthConfig
-    (SharedHandle<AuthConfig>(new AuthConfig("myname", "mypasswd")));
-  SharedHandle<AuthConfig> authConfig = resolver_->resolveAuthConfig("localhost");
-  CPPUNIT_ASSERT_EQUAL(std::string("myname:mypasswd"), authConfig->getAuthText());
+  resolver_->setUserDefinedCred("myname", "mypasswd");
+  auto authConfig = resolver_->resolveAuthConfig("localhost");
+  CPPUNIT_ASSERT_EQUAL(std::string("myname:mypasswd"),
+                       authConfig->getAuthText());
 
   authConfig = resolver_->resolveAuthConfig("mymachine");
-  CPPUNIT_ASSERT_EQUAL(std::string("myname:mypasswd"), authConfig->getAuthText());
+  CPPUNIT_ASSERT_EQUAL(std::string("myname:mypasswd"),
+                       authConfig->getAuthText());
 
-  resolver_->setNetrc(SharedHandle<Netrc>());
+  resolver_->setNetrc(nullptr);
   authConfig = resolver_->resolveAuthConfig("mymachine");
-  CPPUNIT_ASSERT_EQUAL(std::string("myname:mypasswd"), authConfig->getAuthText());
+  CPPUNIT_ASSERT_EQUAL(std::string("myname:mypasswd"),
+                       authConfig->getAuthText());
 }
 
 void NetrcAuthResolverTest::testResolveAuthConfig_ignoreDefault()
 {
   resolver_->ignoreDefault();
-  SharedHandle<AuthConfig> authConfig = resolver_->resolveAuthConfig("mirror");
+  auto authConfig = resolver_->resolveAuthConfig("mirror");
   CPPUNIT_ASSERT_EQUAL(std::string("foo:bar"), authConfig->getAuthText());
 
   resolver_->useDefault();
-  SharedHandle<AuthConfig> defAuthConfig =
-    resolver_->resolveAuthConfig("mirror");
+  auto defAuthConfig = resolver_->resolveAuthConfig("mirror");
   CPPUNIT_ASSERT_EQUAL(std::string("default:defaultpasswd"),
-                       defAuthConfig->getAuthText());  
+                       defAuthConfig->getAuthText());
 }
 
 } // namespace aria2
